Module client

Module client 

Re-exports

pub use types::*;

Modules

types

Structs

Client
StandaloneClient

Enums

ClientWrapper
The underlying connected client held by a Client.

Constants

CONNECTION_CHECKS_INTERVAL
The connection check interval is currently not exposed to the user via ConnectionRequest, as improper configuration could negatively impact performance or pub/sub resiliency. A 3-second interval provides a reasonable balance between connection validation and performance overhead.
DEFAULT_DEFAULT_EXT_SECS
Default extension to the request timeout for blocking commands.
DEFAULT_RESPONSE_TIMEOUT
Note: If you change the default value, make sure to change the documentation in all wrappers.
HEARTBEAT_SLEEP_DURATION

Traits

PubSubCommandApplier
Trait for executing PubSub commands on the internal client wrapper
ValkeyClientForTests

Functions

get_valkey_connection_info
Get Valkey connection info with IAM token integration (when built with feature = "iam").