ObjectType

Enum ObjectType 

pub enum ObjectType {
    String,
    List,
    Set,
    ZSet,
    Hash,
    Stream,
}
Represents the type of an object used to filter keys by data type.

This enum is used with the TYPE option in the SCAN command to filter keys by their data type.

Variants



String

String data type.



List

List data type.



Set

Set data type.



ZSet

Sorted set data type.



Hash

Hash data type.



Stream

Stream data type.