Module value

Module value 

Structs

Error
Represents a valkey error. For the most part you should be using the Error trait to interact with this rather than the actual struct.
InflightRequestTracker
Cloneable handle to an inflight slot. Clone = Arc refcount bump. Last drop triggers InflightSlotGuard::drop which releases the slot.
InfoDict
An info dictionary type.

Enums

ErrorKind
An enum of all error kinds.
ExistenceCheck
Helper enum that is used to define existence checks
Expiry
Helper enum that is used to define expiry time
MapIter
NumericBehavior
Helper enum that is used in some situations to describe the behavior of arguments in a numeric context.
OwnedMapIter
ProtocolVersion
Enum representing the communication protocol with the server. This enum represents the types of data that the server can send to the client, and the capabilities that the client can use.
PushKind
Push type’s currently known kinds.
SetExpiry
Helper enum that is used to define expiry time for SET command
Value
Internal low-level valkey value enum.
VerbatimFormat
VerbatimString’s format types defined by spec

Traits

FromValue
This trait is used to convert a valkey value into a more appropriate type. While a valkey Value can represent any response that comes back from the redis server, usually you want to map this into something that works better in rust. For instance you might want to convert the return value into a String or an integer.
ToArgs
Used to convert a value into one or multiple redis argument strings. Most values will produce exactly one item but in some cases it might make sense to produce more than one.
Write
Abstraction trait for valkey command abstractions.

Functions

from_owned_value
A shortcut function to invoke FromValue::from_owned_value to make the API slightly nicer.
from_value
A shortcut function to invoke FromValue::from_value to make the API slightly nicer.
make_extension_error

Type Aliases

Result
Library generic result type.