pub struct Error { /* private fields */ }Expand description
Represents a valkey error. For the most part you should be using the Error trait to interact with this rather than the actual struct.
Implementations
Sourceimpl Error
Indicates a general failure in the library.
impl Error
Indicates a general failure in the library.
Sourcepub fn err_code(&self) -> &str
pub fn err_code(&self) -> &str
Returns the raw error code if available. Returns the error code string (e.g. “MOVED”, “ERR”, “WRONGTYPE”). Equivalent to the old ServerError::err_code() — returns empty string if no code.
pub fn code(&self) -> Option<&str>
Sourcepub fn is_io_error(&self) -> bool
pub fn is_io_error(&self) -> bool
Indicates that this failure is an IO failure.
Sourcepub fn is_cluster_error(&self) -> bool
pub fn is_cluster_error(&self) -> bool
Indicates that this is a cluster error.
Sourcepub fn is_connection_refusal(&self) -> bool
pub fn is_connection_refusal(&self) -> bool
Returns true if this error indicates that the connection was refused. You should generally not rely much on this function unless you are writing unit tests that want to detect if a local server is available.
Sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Returns true if error was caused by I/O time out. Note that this may not be accurate depending on platform.
Sourcepub fn is_connection_dropped(&self) -> bool
pub fn is_connection_dropped(&self) -> bool
Returns true if error was caused by a dropped connection.
Sourcepub fn is_unrecoverable_error(&self) -> bool
pub fn is_unrecoverable_error(&self) -> bool
Returns true if the error is likely to not be recoverable, and the connection must be replaced.
Sourcepub fn redirect_node(&self) -> Option<(&str, u16)>
pub fn redirect_node(&self) -> Option<(&str, u16)>
Returns the node the error refers to.
This returns (addr, slot_id).