Ferriskey — a Rust client for Valkey.
Forked from glide-core (valkey-glide), descended from redis-rs. Refactored for FlowFabric: ClientBuilder API, first-class FCALL support, no URL-based connections required.
Re-exports
pub use cmd::Cmd;pub use cmd::cmd;pub use cmd::pipe;pub use value::Error;pub use value::ErrorKind;pub use value::FromValue;pub use value::InfoDict;pub use value::ProtocolVersion;pub use value::PushKind;pub use value::Result;pub use value::ToArgs;pub use value::Value;pub use value::from_owned_value;pub use value::from_value;pub use value::Result as ValkeyResult;pub use ferriskey_client::ReadFrom;pub use cluster::scan::ClusterScanArgs;pub use cluster::scan::ClusterScanArgsBuilder;pub use cluster::scan::ObjectType;pub use cluster::scan::ScanStateRC;
Modules
- client
- cluster
- This module provides async functionality for Valkey Cluster.
- cmd
- compression
- Compression module providing automatic compression and decompression capabilities for Valkey Glide client operations.
- connection
- Adds async IO support to redis.
- pipeline
- protocol
- RESP protocol parsing and codec.
- pubsub
- request_
type - value
Structs
- Client
- High-level Valkey client with convenience methods for common operations.
- Client
Builder - Builder for constructing a
Clientwith custom connection options. - Command
Builder - Builder for executing an arbitrary command through a
Client. - Connection
Info - Holds the connection information that redis should use for connecting.
- Lazy
Client - A client handle whose underlying TCP connection is established on first use, not at construction.
- Pipe
CmdBuilder - Builder for adding an arbitrary command to a
TypedPipeline. - Pipe
Slot - A handle to a single result within a
TypedPipeline. - Push
Info - Holds information about received Push data
- Retry
Strategy - This struct represents the exponential backoff parameters for reconnection attempts.
- Telemetry
Deprecated - Backwards-compatibility stub. All methods are no-ops; counter reads
return the identity element (
0). See the module-level comment for migration guidance. - Typed
Pipeline - A typed pipeline that returns
PipeSlothandles for each command. - Valkey
Connection Info - Valkey connection information used to establish a connection.
Enums
- Connection
Addr - Defines the connection address.
- PubSub
Subscription Kind - Types of pubsub subscriptions
- TlsMode
- TlsMode indicates use or do not use verification of certification.
Traits
- Into
Connection Info - Converts an object into a connection info struct.
Functions
- connect
- Connect to a standalone Valkey server.
- connect_
cluster - Connect to a Valkey cluster.
Type Aliases
- PubSub
Channel OrPattern - Type for pubsub channels/patterns
- PubSub
Subscription Info - Type for pubsub channels/patterns