Re-exports
pub use types::*;
Modules
Structs
Enums
- Client
Wrapper - The underlying connected client held by a
Client.
Constants
- CONNECTION_
CHECKS_ INTERVAL - The connection check interval is currently not exposed to the user via ConnectionRequest, as improper configuration could negatively impact performance or pub/sub resiliency. A 3-second interval provides a reasonable balance between connection validation and performance overhead.
- DEFAULT_
DEFAULT_ EXT_ SECS - Default extension to the request timeout for blocking commands.
- DEFAULT_
RESPONSE_ TIMEOUT - Note: If you change the default value, make sure to change the documentation in all wrappers.
- HEARTBEAT_
SLEEP_ DURATION
Traits
- PubSub
Command Applier - Trait for executing PubSub commands on the internal client wrapper
- Valkey
Client ForTests
Functions
- get_
valkey_ connection_ info - Get Valkey connection info with IAM token integration (when built
with
feature = "iam").