Enum representing the communication protocol with the server. This enum represents the types
of data that the server can send to the client, and the capabilities that the client can use.
This trait is used to convert a valkey value into a more appropriate
type. While a valkey Value can represent any response that comes
back from the redis server, usually you want to map this into something
that works better in rust. For instance you might want to convert the
return value into a String or an integer.
Used to convert a value into one or multiple redis argument
strings. Most values will produce exactly one item but in
some cases it might make sense to produce more than one.